@@ -3,6 +3,14 @@ package Geo::Address::Parser::Rules::NZ;
 use strict;
 use warnings;
 
+=head1 VERSION
+
+Version 0.06
+
+=cut
+
+our $VERSION = '0.06';
+
 use Exporter 'import';
 our @EXPORT_OK = qw(parse_address);
 
@@ -15,7 +23,7 @@ sub parse_address {
 
 	my @parts = map { s/^\s+|\s+$//gr } split /,/, $text;
 
-	my ($name, $street, $suburb, $city, $postcode);
+	my ($name, $road, $suburb, $city, $postcode);
 
 	if ($parts[-1] =~ /(.+?)\s+($postcode_re)$/) {
 		$postcode = $2;
@@ -24,12 +32,12 @@ sub parse_address {
 
 	$city = pop @parts if @parts;
 	$suburb = pop @parts if @parts;
-	$street = pop @parts if @parts;
+	$road = pop @parts if @parts;
 	$name = join(', ', @parts) if @parts;
 
 	return {
 		name => $name,
-		street => $street,
+		road => $road,
 		suburb => $suburb,
 		city => $city,
 		postcode => $postcode,
@@ -46,7 +54,7 @@ Geo::Address::Parser::Rules::NZ - Parsing rules for New Zealand addresses
 
 =head1 DESCRIPTION
 
-Parses a flat New Zealand address string into components: name, street, suburb, city, postcode.
+Parses a flat New Zealand address string into components: name, road, suburb, city, postcode.
 
 =head1 EXPORTS
 
@@ -58,7 +66,7 @@ Returns a hashref with keys:
 
 =item * name
 
-=item * street
+=item * road
 
 =item * suburb
 
